Free Python Games API Reference
===============================

:doc:`Free Python Games <index>` includes a few helpful utilities. The best way
to expose beginners to these functions is with Python's built-in help
function. Learners should be able to understand and write the drawing functions
themselves.

.. contents::
   :local:

Drawing Functions
-----------------

.. autofunction:: freegames.line

.. autofunction:: freegames.square

Helper Functions
----------------

.. autofunction:: freegames.floor

.. autofunction:: freegames.path

Vectors
-------

.. autoclass:: freegames.vector
   :members:
   :special-members:
